@@ -32,11 +32,11 @@ impl Overlay for MetaOverlay {
     fn add(&mut self, _attribute: &Attribute) {}
 }
 impl MetaOverlay {
-    pub fn new(lang: &Language, oca_tr: &OCATranslation) -> Box<MetaOverlay> {
+    pub fn new(lang: Language, oca_tr: &OCATranslation) -> Box<MetaOverlay> {
         Box::new(MetaOverlay {
             capture_base: String::new(),
             overlay_type: "spec/overalys/meta/1.0".to_string(),
-            language: *lang,
+            language: lang,
             name: oca_tr.name.as_ref().unwrap_or(&"".to_string()).clone(),
             description: oca_tr
                 .description
